@@ -60,6 +60,7 @@ impl Display for Error {
                     Debug::fmt(body, f)
                 }
             }
+            ErrorType::RatelimiterTicket => f.write_str("Failed to get ratelimiter ticket"),
             ErrorType::RequestCanceled => {
                 f.write_str("Request was canceled either before or while being sent")
             }
@@ -103,6 +104,7 @@ pub enum ErrorType {
     Parsing {
         body: Vec<u8>,
     },
+    RatelimiterTicket,
     RequestCanceled,
     RequestError,
     RequestTimedOut,
