@@ -33,9 +33,9 @@ impl<'a> GetGuildCommand<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Command> {
         let request = Request::from_route(&Route::GetGuildCommand {
-            application_id: self.application_id.0,
-            command_id: self.command_id.0,
-            guild_id: self.guild_id.0,
+            application_id: self.application_id.get(),
+            command_id: self.command_id.get(),
+            guild_id: self.guild_id.get(),
         });
 
         self.http.request(request)
