@@ -32,7 +32,7 @@ impl<'a> DeleteChannelPermissionConfigured<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
         let mut request = Request::builder(&Route::DeletePermissionOverwrite {
-            channel_id: self.channel_id.0,
+            channel_id: self.channel_id.get(),
             target_id: self.target_id,
         });
 
