@@ -14,7 +14,8 @@ use twilight_model::{
 
 #[derive(Serialize)]
 struct CreateThreadFields<'a> {
-    auto_archive_duration: AutoArchiveDuration,
+    #[serde(skip_serializing_if = "Option::is_none")]
+    auto_archive_duration: Option<AutoArchiveDuration>,
     #[serde(skip_serializing_if = "Option::is_none")]
     invitable: Option<bool>,
     #[serde(rename = "type")]
@@ -45,7 +46,6 @@ impl<'a> CreateThread<'a> {
         http: &'a Client,
         channel_id: ChannelId,
         name: &'a str,
-        auto_archive_duration: AutoArchiveDuration,
         kind: ChannelType,
     ) -> Result<Self, ThreadValidationError> {
         if !validate_inner::channel_name(name) {
@@ -63,7 +63,7 @@ impl<'a> CreateThread<'a> {
         Ok(Self {
             channel_id,
             fields: CreateThreadFields {
-                auto_archive_duration,
+                auto_archive_duration: None,
                 invitable: None,
                 kind,
                 name,
@@ -72,6 +72,23 @@ impl<'a> CreateThread<'a> {
         })
     }
 
+    /// Set the thread's auto archive duration.
+    ///
+    /// Values of [`ThreeDays`] and [`Week`] require the guild to be boosted.
+    /// The guild's features will indicate if a guild is able to use these
+    /// settings.
+    ///
+    /// [`ThreeDays`]: twilight_model::channel::thread::AutoArchiveDuration::ThreeDays
+    /// [`Week`]: twilight_model::channel::thread::AutoArchiveDuration::Week
+    pub const fn auto_archive_duration(
+        mut self,
+        auto_archive_duration: AutoArchiveDuration,
+    ) -> Self {
+        self.fields.auto_archive_duration = Some(auto_archive_duration);
+
+        self
+    }
+
     /// Whether non-moderators can add other non-moderators to a thread.
     pub const fn invitable(mut self, invitable: bool) -> Self {
         self.fields.invitable = Some(invitable);
