@@ -109,8 +109,6 @@ pub(crate) struct ExecuteWebhookFields<'a> {
     #[serde(skip_serializing_if = "Option::is_none")]
     payload_json: Option<&'a [u8]>,
     #[serde(skip_serializing_if = "Option::is_none")]
-    thread_id: Option<ChannelId>,
-    #[serde(skip_serializing_if = "Option::is_none")]
     tts: Option<bool>,
     #[serde(skip_serializing_if = "Option::is_none")]
     username: Option<&'a str>,
@@ -149,6 +147,7 @@ pub struct ExecuteWebhook<'a> {
     attachments: Cow<'a, [AttachmentFile<'a>]>,
     pub(crate) fields: ExecuteWebhookFields<'a>,
     pub(super) http: &'a Client,
+    thread_id: Option<ChannelId>,
     token: &'a str,
     webhook_id: WebhookId,
 }
@@ -163,13 +162,13 @@ impl<'a> ExecuteWebhook<'a> {
                 content: None,
                 embeds: None,
                 payload_json: None,
-                thread_id: None,
                 tts: None,
                 username: None,
                 allowed_mentions: None,
             },
             attachments: Cow::Borrowed(&[]),
             http,
+            thread_id: None,
             token,
             webhook_id,
         }
@@ -320,7 +319,7 @@ impl<'a> ExecuteWebhook<'a> {
 
     /// Execute in a thread belonging to the channel instead of the channel itself.
     pub fn thread_id(mut self, thread_id: ChannelId) -> Self {
-        self.fields.thread_id.replace(thread_id);
+        self.thread_id.replace(thread_id);
 
         self
     }
@@ -354,6 +353,7 @@ impl<'a> ExecuteWebhook<'a> {
     // being consumed in request construction.
     pub(super) fn request(&mut self, wait: bool) -> Result<Request, HttpError> {
         let mut request = Request::builder(&Route::ExecuteWebhook {
+            thread_id: self.thread_id.map(ChannelId::get),
             token: self.token,
             wait: Some(wait),
             webhook_id: self.webhook_id.get(),
