@@ -68,7 +68,7 @@ impl<'a> CreateEmoji<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Emoji> {
         let mut request = Request::builder(&Route::CreateEmoji {
-            guild_id: self.guild_id.0,
+            guild_id: self.guild_id.get(),
         });
 
         request = match request.json(&self.fields) {
