@@ -37,9 +37,9 @@ impl<'a> RemoveRoleFromMember<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<EmptyBody> {
         let mut request = Request::builder(&Route::RemoveMemberRole {
-            guild_id: self.guild_id.0,
-            role_id: self.role_id.0,
-            user_id: self.user_id.0,
+            guild_id: self.guild_id.get(),
+            role_id: self.role_id.get(),
+            user_id: self.user_id.get(),
         });
 
         if let Some(reason) = self.reason {
