@@ -23,7 +23,7 @@ impl<'a> SyncTemplate<'a> {
     /// [`Response`]: crate::response::Response
     pub fn exec(self) -> ResponseFuture<Template> {
         let request = Request::from_route(&Route::SyncTemplate {
-            guild_id: self.guild_id.0,
+            guild_id: self.guild_id.get(),
             template_code: self.template_code,
         });
 
